# Generated by Django 6.0.3 on 2026-03-18 16:26

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('terminusgps_notifier', '0003_alter_terminusgpsnotifiercustomer_tax_rate'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='terminusgpsnotifiercustomer',
            name='token',
        ),
        migrations.DeleteModel(
            name='WialonToken',
        ),
    ]
